@@ -8,7 +8,7 @@ package Tickit;
 use strict;
 use warnings;
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 use IO::Handle;
 
@@ -121,6 +121,7 @@ sub new
          writer        => $writer,
          input_handle  => $in,
          output_handle => $out,
+         UTF8          => $args{UTF8},
       );
    }
 
@@ -130,7 +131,7 @@ sub new
 
    my $rootwin = $self->{rootwin} = Tickit::Window->new( $self, $term->lines, $term->cols );
 
-   $self->bind_key( 'C-c' => $self->can( "_STOP" ) );
+   $self->bind_key( 'C-c' => $self->can( "stop" ) );
 
    weaken( my $weakself = $self );
 
@@ -272,7 +273,7 @@ previous callback for the same key. The code block is invoked as
 If C<$code> is missing or C<undef>, any existing callback is removed.
 
 As a convenience for the common application use case, the C<Ctrl-C> key is
-bound to the C<_STOP> method.
+bound to the C<stop> method.
 
 To remove this binding, simply bind another callback, or remove the binding
 entirely by setting C<undef>.
@@ -366,12 +367,6 @@ sub teardown_term
    $term->mode_mouse( 0 );
 }
 
-sub _STOP
-{
-   my $self = shift;
-   $self->{keep_running} = 0;
-}
-
 =head2 $tickit->tick
 
 Run a single round of IO events. Does not call C<setup_term> or
@@ -408,7 +403,7 @@ sub tick
 =head2 $tickit->run
 
 Calls the C<setup_term> method, then processes IO events until stopped, by the
-C<_STOP> method, C<SIGINT>, C<SIGTERM> or the C<Ctrl-C> key. Then runs the
+C<stop> method, C<SIGINT>, C<SIGTERM> or the C<Ctrl-C> key. Then runs the
 C<teardown_term> method, and returns.
 
 =cut
@@ -419,7 +414,7 @@ sub run
 
    $self->setup_term;
 
-   $SIG{INT} = $SIG{TERM} = sub { $self->_STOP };
+   $SIG{INT} = $SIG{TERM} = sub { $self->stop };
 
    $SIG{WINCH} = sub { 
       $self->later( sub { $self->_SIGWINCH } )
@@ -443,6 +438,18 @@ sub run
    $self->teardown_term;
 }
 
+=head2 $tickit->stop
+
+Causes a currently-running C<run> method to stop processing events and return.
+
+=cut
+
+sub stop
+{
+   my $self = shift;
+   $self->{keep_running} = 0;
+}
+
 =head1 AUTHOR
 
 Paul Evans <leonerd@leonerd.org.uk>
