@@ -8,7 +8,7 @@ package Tickit::Pen;
 use strict;
 use warnings;
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 use Carp;
 use Scalar::Util qw( weaken );
@@ -117,6 +117,20 @@ sub clone
 
 =cut
 
+=head2 $exists = $pen->hasattr( $attr )
+
+Returns true if the given attribute exists on this object
+
+=cut
+
+sub hasattr
+{
+   my $self = shift;
+   my ( $attr ) = @_;
+
+   return exists $self->{$attr};
+}
+
 =head2 $value = $pen->getattr( $attr )
 
 Returns the current value of the given attribute
@@ -141,7 +155,8 @@ sub getattrs
 {
    my $self = shift;
 
-   return map { $_ => $self->{$_} } grep { !m/^_/ } keys %$self;
+   return map { $_ => $self->getattr( $_ ) }
+          grep { $self->hasattr( $_ ) } @ALL_ATTRS;
 }
 
 =head2 $pen->chattr( $attr, $value )
@@ -157,10 +172,10 @@ sub chattr
    my ( $attr, $val ) = @_;
 
    my $canonicalise = $self->can( "_canonicalise_$attr" );
-   $val = $self->$canonicalise( $val ) if $canonicalise;
+   $val = $self->$canonicalise( $val ) if $canonicalise and defined $val;
 
    # Optimise
-   my $curval = $self->{$attr};
+   my $curval = $self->getattr( $attr );
    return if !defined $curval and !defined $val;
    return if  defined $curval and  defined $val and $val == $curval;
 
@@ -266,8 +281,8 @@ sub copy_from
    my $changed;
    my %other = $other->getattrs;
    foreach my $attr ( keys %other ) {
-      ( !exists $self->{$attr} or $self->{$attr} != $other{$attr} ) and
-         $self->{$attr} = $other{$attr}, $changed = 1;
+      ( !$self->hasattr( $attr ) or $self->getattr( $attr ) != $other{$attr} ) and
+         $self->chattr( $attr => $other{$attr} ), $changed = 1;
    }
 
    $self->_changed if $changed;
@@ -282,8 +297,8 @@ sub default_from
    my $changed;
    my %other = $other->getattrs;
    foreach my $attr ( keys %other ) {
-      !exists $self->{$attr} and
-         $self->{$attr} = $other{$attr}, $changed = 1;
+      !$self->hasattr( $attr ) and
+         $self->chattr( $attr => $other{$attr} ), $changed = 1;
    }
 
    $self->_changed if $changed;
