@@ -8,11 +8,11 @@ package Tickit::Term;
 use strict;
 use warnings;
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 use Encode qw( find_encoding );
 use Term::Size;
-use Term::TermKey 0.11 qw( FORMAT_ALTISMETA FLAG_UTF8 FLAG_RAW FLAG_EINTR RES_KEY RES_AGAIN );
+use Term::TermKey 0.11 qw( FORMAT_ALTISMETA FLAG_UTF8 FLAG_RAW FLAG_EINTR RES_KEY RES_AGAIN CANON_DELBS );
 use Term::Terminfo;
 use Time::HiRes qw( time );
 
@@ -83,6 +83,12 @@ Takes the following named arguments at construction time:
 Optional. If supplied, applies the named encoding to the Unicode string
 supplied to the C<print> method.
 
+=item UTF8 => BOOL
+
+If defined, overrides locale detection to enable or disable UTF-8 mode. If not
+defined then this will be detected from the locale by using Perl's
+C<${^UTF8LOCALE}> variable.
+
 =item writer => OBJECT
 
 An object delegated to for sending strings of terminal control bytes to the
@@ -149,6 +155,8 @@ sub new
    $termkey->set_flags( ( $termkey->get_flags & ~FLAGS_UTF8_RAW ) |
                         ( $is_utf8 ? FLAG_UTF8 : FLAG_RAW ) );
 
+   $termkey->set_canonflags( $termkey->get_canonflags | CANON_DELBS );
+
    $encoding = "UTF-8" if $is_utf8;
 
    my $self = bless {
